@@ -87,7 +87,8 @@ private Q_SLOTS:
         fetch->fetchScope().fetchFullPayload();
         AKVERIFYEXEC(fetch);
         QCOMPARE(fetch->items().count(), items.count() + baseline);
-        foreach (const Item &movedItem, fetch->items()) {
+        const Item::List movedItemList = fetch->items();
+        for (const Item &movedItem : movedItemList) {
             QVERIFY(movedItem.hasPayload());
             QVERIFY(!movedItem.payload<QByteArray>().isEmpty());
             if (destination.id() >= 0) {
@@ -100,7 +101,7 @@ private Q_SLOTS:
         QTRY_COMPARE(moveSpy.count(), 1);
         const Akonadi::Item::List &ntfItems = moveSpy.takeFirst().at(0).value<Akonadi::Item::List>();
         QCOMPARE(ntfItems.size(), items.size());
-        Q_FOREACH (const Item &ntfItem, ntfItems) {
+        for (const Item &ntfItem : ntfItems) {
             if (destination.id() >= 0) {
                 QCOMPARE(ntfItem.parentCollection().id(), destination.id());
             } else {
